import React, { Suspense, lazy } from 'react';
import { Shield, Target, Eye, Zap, Home, Users, CheckCircle } from 'lucide-react';
import OptimizedTimer from './components/OptimizedTimer';

// Lazy load components that are below the fold
const LazySection = lazy(() => import('./components/LazySection'));
const FAQ = lazy(() => import('./components/FAQ'));
const TestimonialCard = lazy(() => import('./components/TestimonialCard'));

function App() {
  const paymentLink = "https://pay.kiwify.com.br/UMBhszp?fbclid=PAQ0xDSwLTqf5leHRuA2FlbQExAAGn4jaVhwOGgGOkDAS64mGoFedKoNsVM897if64m_G5pQcJ6sTdNAWsjb40Ezo_aem_f-MsraiHYU6STq2-KI7d5A";

  const scrollToOffer = () => {
    const priceButton = document.getElementById('price-button');
    if (priceButton) {
      // Pequeno delay para garantir que o DOM está pronto
      setTimeout(() => {
        priceButton.scrollIntoView({ 
          behavior: 'smooth',
          block: 'center',
          inline: 'nearest'
        });
      }, 100);
    }
  };

  // Alternativa usando scroll manual para mais controle
  const scrollToOfferManual = () => {
    const priceButton = document.getElementById('price-button');
    if (priceButton) {
      const rect = priceButton.getBoundingClientRect();
      const scrollTop = window.pageYOffset || document.documentElement.scrollTop;
      const targetPosition = scrollTop + rect.top - (window.innerHeight / 2) + (rect.height / 2);
      
      window.scrollTo({
        behavior: 'smooth',
        top: targetPosition
      });
    }
  };

  const faqData = [
    {
      icon: "🧠",
      question: "Esse conteúdo serve mesmo pra quem mora em cidade grande?",
      answer: "Sim!\nO Manual foi criado exatamente pra quem vive em ambiente urbano — sem depender de floresta, mato ou isolamento.\nVocê vai aprender como se preparar com o que tem à disposição agora, mesmo morando em apartamento."
    },
    {
      icon: "🛠️",
      question: "Preciso ter algum equipamento ou kit tático pra aplicar o que é ensinado?",
      answer: "Não precisa.\nVocê pode começar do zero absoluto.\nO Manual te ensina a montar seu kit passo a passo, com sugestões acessíveis e realistas, respeitando o seu nível atual."
    },
    {
      icon: "📘",
      question: "Isso é só um ebook?",
      answer: "Definitivamente, não.\nVocê vai ter acesso a um sistema completo de preparação urbana, com estrutura lógica, orientações práticas e mentalidade estratégica.\nChamar de \"ebook\" seria diminuir demais o que ele entrega."
    },
    {
      icon: "🧨",
      question: "Nunca estudei sobrevivencialismo, vou entender?",
      answer: "Vai sim.\nO conteúdo foi pensado pra quem ainda não sabe por onde começar, sem jargões complicados ou instruções impossíveis.\nTudo é direto ao ponto e aplicável."
    },
    {
      icon: "🔐",
      question: "Por quanto tempo terei acesso ao material?",
      answer: "Acesso vitalício.\nUma vez adquirido, é seu. Simples assim."
    },
    {
      icon: "💸",
      question: "E se eu comprar e não curtir?",
      answer: "Você tem 7 dias de garantia incondicional.\nSe por qualquer motivo achar que não é pra você, é só pedir reembolso e o dinheiro volta sem questionamento."
    },
    {
      icon: "⏳",
      question: "Essa oferta é por tempo limitado?",
      answer: "Sim.\nEssa condição de preço especial está disponível apenas durante o lançamento e pode ser encerrada a qualquer momento, sem aviso prévio."
    }
  ];

  const testimonials = [
    {
      initials: "MC",
      name: "Marcos C.",
      testimonial: "Finalmente um material que fala a nossa língua. Nada de frescura, só o que realmente funciona."
    },
    {
      initials: "RS",
      name: "Rafael S.",
      testimonial: "Mudou minha mentalidade completamente. Agora durmo tranquilo sabendo que posso proteger minha família."
    },
    {
      initials: "AL",
      name: "André L.",
      testimonial: "Informações que você não encontra em lugar nenhum. Valeu cada centavo investido."
    }
  ];

  return (
    <div className="min-h-screen bg-gray-900 text-white">
      {/* Barra de Urgência */}
      <OptimizedTimer initialTime={6 * 60 + 14} />

      {/* 1. BLOCO HERO - Critical above-the-fold content */}
      <section className="relative bg-black py-20 px-4">
        <div className="max-w-6xl mx-auto text-center">
          <h1 className="text-4xl md:text-6xl font-bold mb-6 leading-tight">
            Se hoje faltar energia, comida ou segurança...{' '}
            <span className="text-orange-500">você sabe o que fazer?</span>
          </h1>
          <p className="text-xl md:text-2xl mb-8 text-gray-300 max-w-4xl mx-auto">
            Descubra o melhor Guia de sobrevivêncialismo que já despertou milhares de homens comuns 
            para o instinto mais poderoso que existe: <span className="text-orange-500 font-bold">sobreviver.</span>
          </p>
          <div className="mb-8">
            <img 
              src="https://i.imgur.com/11UTXYS.webp" 
              alt="Manual do Sobrevivencialista Moderno" 
              className="mx-auto max-w-md w-full h-auto rounded-lg shadow-lg"
              loading="eager"
            />
          </div>
          <button 
            onClick={scrollToOfferManual}
            className="bg-orange-500 hover:bg-orange-600 text-black font-bold py-4 px-8 rounded-lg text-xl transition-all duration-300 transform hover:scale-105"
          >
            QUERO ME PREPARAR AGORA
          </button>
        </div>
      </section>

      {/* Lazy load sections below the fold */}
      <Suspense fallback={<div className="min-h-[200px] bg-gray-800" />}>
        <LazySection className="py-16 px-4 bg-gray-800">
          <div className="max-w-4xl mx-auto">
            <div className="text-center mb-12">
              <h2 className="text-3xl md:text-4xl font-bold mb-6">
                Eu já estive no seu lugar... <span className="text-orange-500">totalmente despreparado</span>
              </h2>
              <div className="space-y-4 text-lg text-gray-300">
                <p>Achava que nunca ia acontecer nada comigo.</p>
                <p>Que o governo sempre ia resolver tudo.</p>
                <p>Que a tecnologia ia me salvar de qualquer problema.</p>
                <p className="text-orange-500 font-bold">Até o dia em que a realidade bateu na minha porta.</p>
              </div>
            </div>
          </div>
        </LazySection>
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-gray-900" />}>
        <LazySection className="py-16 px-4 bg-gray-900">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-3xl md:text-4xl font-bold mb-8">
              <span className="text-orange-500">O sistema quer você fraco, passivo e dependente.</span>
            </h2>
            <div className="grid md:grid-cols-3 gap-8 mb-12">
              <div className="bg-gray-800 p-6 rounded-lg border-l-4 border-orange-500">
                <Target className="w-12 h-12 text-orange-500 mb-4 mx-auto" />
                <h3 className="text-xl font-bold mb-2">Ilusão de Segurança</h3>
                <p className="text-gray-300">Te convencem que você está protegido, mas na primeira crise...</p>
              </div>
              <div className="bg-gray-800 p-6 rounded-lg border-l-4 border-orange-500">
                <Eye className="w-12 h-12 text-orange-500 mb-4 mx-auto" />
                <h3 className="text-xl font-bold mb-2">Controle Total</h3>
                <p className="text-gray-300">Dependência completa do sistema para sobreviver</p>
              </div>
              <div className="bg-gray-800 p-6 rounded-lg border-l-4 border-orange-500">
                <Zap className="w-12 h-12 text-orange-500 mb-4 mx-auto" />
                <h3 className="text-xl font-bold mb-2">Manipulação</h3>
                <p className="text-gray-300">Você é mantido no modo automático, sem pensar</p>
              </div>
            </div>
          </div>
        </LazySection>
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-gray-700" />}>
        <LazySection className="py-16 px-4 bg-gray-700">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-3xl md:text-4xl font-bold mb-8">
              Existe um caminho. E ele começa com <span className="text-orange-500">conhecimento.</span>
            </h2>
            <p className="text-xl text-gray-300 mb-8">
              Não precisa virar um eremita ou morar no mato. Você pode se preparar sendo um homem urbano, 
              moderno, mas com o instinto de sobrevivência desperto.
            </p>
          </div>
        </LazySection>
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-black" />}>
        <LazySection className="py-16 px-4 bg-black">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-3xl md:text-4xl font-bold mb-8">
              <span className="text-orange-500">O Manual do Sobrevivêncialista Moderno</span>
            </h2>
            <div className="grid md:grid-cols-2 gap-8">
              <div className="bg-gray-800 p-6 rounded-lg">
                <CheckCircle className="w-8 h-8 text-orange-500 mb-4" />
                <h3 className="text-xl font-bold mb-2">Preparação Urbana</h3>
                <p className="text-gray-300">Sem precisar morar no mato ou virar um maluco</p>
              </div>
              <div className="bg-gray-800 p-6 rounded-lg">
                <CheckCircle className="w-8 h-8 text-orange-500 mb-4" />
                <h3 className="text-xl font-bold mb-2">Estratégias Reais</h3>
                <p className="text-gray-300">Métodos testados por quem já viveu situações extremas</p>
              </div>
              <div className="bg-gray-800 p-6 rounded-lg">
                <CheckCircle className="w-8 h-8 text-orange-500 mb-4" />
                <h3 className="text-xl font-bold mb-2">Mentalidade de Sobrevivente</h3>
                <p className="text-gray-300">Desperte o instinto que todo homem deveria ter</p>
              </div>
              <div className="bg-gray-800 p-6 rounded-lg">
                <CheckCircle className="w-8 h-8 text-orange-500 mb-4" />
                <h3 className="text-xl font-bold mb-2">Aplicável no Dia a Dia</h3>
                <p className="text-gray-300">Conhecimento que você usa sempre, não só em crises</p>
              </div>
            </div>
          </div>
        </LazySection>
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-gray-800" />}>
        <LazySection className="py-16 px-4 bg-gray-800">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl md:text-4xl font-bold mb-8 text-center">
              Quem está por trás do <span className="text-orange-500">Manual</span>
            </h2>
            <div className="flex flex-col md:flex-row items-center gap-8">
              <div className="w-48 h-48 bg-gray-700 rounded-lg flex items-center justify-center">
                <Shield className="w-20 h-20 text-orange-500" />
              </div>
              <div className="flex-1">
                <h3 className="text-2xl font-bold mb-4">Criador do Instinto Bruto</h3>
                <div className="space-y-4 text-gray-300">
                  <p>Eu era um homem comum, até que situações reais me mostraram o quão vulnerável eu estava. Foi aí que decidi mudar...</p>
                  <p>Depois de passar por essas situações, 
                     dediquei anos da minha vida estudando e testando métodos de sobrevivência urbana.</p>
                  <p>Hoje, mais de 10.000 homens já acordaram do sono profundo e assumiram o controle 
                     da própria segurança através dos meus métodos.</p>
                  <p className="text-orange-500 font-bold">E você pode ser o próximo.</p>
                </div>
              </div>
            </div>
          </div>
        </LazySection>
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-gray-900" />}>
        <LazySection className="py-16 px-4 bg-gray-900">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl md:text-4xl font-bold mb-12 text-center">
              O que dizem os homens que já se <span className="text-orange-500">prepararam</span>
            </h2>
            <div className="grid md:grid-cols-3 gap-8">
              {testimonials.map((testimonial, index) => (
                <TestimonialCard
                  key={index}
                  initials={testimonial.initials}
                  name={testimonial.name}
                  testimonial={testimonial.testimonial}
                />
              ))}
            </div>
          </div>
        </LazySection>
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-black" />}>
        <LazySection className="py-16 px-4 bg-black">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl md:text-4xl font-bold mb-12 text-center">
              Dentro do Manual, você vai aprender a...
            </h2>
            <div className="grid md:grid-cols-2 gap-6">
              <div className="flex items-start gap-4">
                <Shield className="w-8 h-8 text-orange-500 mt-1" />
                <div>
                  <h3 className="text-xl font-bold mb-2">Montar seu Kit Tático Urbano</h3>
                  <p className="text-gray-300">Itens essenciais que cabem numa mochila e podem salvar sua vida</p>
                </div>
              </div>
              <div className="flex items-start gap-4">
                <Target className="w-8 h-8 text-orange-500 mt-1" />
                <div>
                  <h3 className="text-xl font-bold mb-2">Criar Planos de Ação</h3>
                  <p className="text-gray-300">Estratégias para diferentes cenários de crise urbana</p>
                </div>
              </div>
              <div className="flex items-start gap-4">
                <Zap className="w-8 h-8 text-orange-500 mt-1" />
                <div>
                  <h3 className="text-xl font-bold mb-2">Lidar com Escassez</h3>
                  <p className="text-gray-300">Como se virar quando falta luz, água, comida ou combustível</p>
                </div>
              </div>
              <div className="flex items-start gap-4">
                <Home className="w-8 h-8 text-orange-500 mt-1" />
                <div>
                  <h3 className="text-xl font-bold mb-2">Proteger Casa e Família</h3>
                  <p className="text-gray-300">Segurança residencial e proteção dos que você ama</p>
                </div>
              </div>
              <div className="flex items-start gap-4">
                <Eye className="w-8 h-8 text-orange-500 mt-1" />
                <div>
                  <h3 className="text-xl font-bold mb-2">Desenvolver Consciência Situacional</h3>
                  <p className="text-gray-300">Como identificar perigos antes que aconteçam</p>
                </div>
              </div>
              <div className="flex items-start gap-4">
                <Users className="w-8 h-8 text-orange-500 mt-1" />
                <div>
                  <h3 className="text-xl font-bold mb-2">Formar Rede de Apoio</h3>
                  <p className="text-gray-300">Construir alianças estratégicas com outros preparados</p>
                </div>
              </div>
            </div>
          </div>
        </LazySection>
      </Suspense>

      {/* OFERTA - Keep this visible as it's important for conversion */}
      <section id="offer-section" className="py-16 px-4 bg-gray-800">
        <div className="max-w-4xl mx-auto text-center">
          <h2 className="text-3xl md:text-4xl font-bold mb-8">
            <span className="text-orange-500">Oferta Especial</span> Por Tempo Limitado
          </h2>
          <div className="bg-black p-8 rounded-lg mb-8">
            <p className="text-2xl mb-4 text-gray-300">
              Enquanto muita gente cobra caro por pouco, eu resolvi liberar o que custava <span className="line-through text-red-500">R$ 197</span> por apenas:
            </p>
            <div className="text-6xl font-bold text-orange-500 mb-4">R$ 47</div>
            <div className="space-y-2 text-gray-300 mb-6">
              <p>✓ Acesso imediato após o pagamento</p>
              <p>✓ Garantia incondicional de 7 dias</p>
              <p>✓ Sem mensalidades ou taxas ocultas</p>
              <p>✓ Risco zero para você</p>
            </div>
            <a href={paymentLink} target="_blank" rel="noopener noreferrer">
              <button id="price-button" className="bg-orange-500 hover:bg-orange-600 text-black font-bold py-4 px-8 rounded-lg text-2xl transition-all duration-300 transform hover:scale-105">
                QUERO ACESSAR O MANUAL AGORA
              </button>
            </a>
          </div>
          <p className="text-sm text-gray-400">
            Pagamento 100% seguro via cartão de crédito ou PIX
          </p>
        </div>
      </section>

      <Suspense fallback={<div className="min-h-[200px] bg-gray-700" />}>
        <LazySection className="py-16 px-4 bg-gray-700">
          <div className="max-w-4xl mx-auto">
            <div className="bg-gray-800 border-2 border-orange-500 rounded-lg p-8 text-center">
              <div className="flex justify-center mb-6">
                <div className="w-20 h-20 bg-orange-500 rounded-full flex items-center justify-center">
                  <Shield className="w-10 h-10 text-black" />
                </div>
              </div>
              <h2 className="text-3xl font-bold mb-4">
                <span className="text-orange-500">Garantia Incondicional</span> de 7 Dias
              </h2>
              <p className="text-xl text-gray-300 mb-6">
                Se por qualquer motivo você não ficar 100% satisfeito com o Manual do Sobrevivencialista Moderno, 
                eu devolverei todo o seu dinheiro sem fazer perguntas.
              </p>
              <div className="grid md:grid-cols-3 gap-6 text-left">
                <div className="flex items-start gap-3">
                  <CheckCircle className="w-6 h-6 text-orange-500 mt-1 flex-shrink-0" />
                  <div>
                    <h3 className="font-bold mb-1">Sem Perguntas</h3>
                    <p className="text-gray-300 text-sm">Não precisa justificar nada</p>
                  </div>
                </div>
                <div className="flex items-start gap-3">
                  <CheckCircle className="w-6 h-6 text-orange-500 mt-1 flex-shrink-0" />
                  <div>
                    <h3 className="font-bold mb-1">Reembolso Total</h3>
                    <p className="text-gray-300 text-sm">100% do valor pago de volta</p>
                  </div>
                </div>
                <div className="flex items-start gap-3">
                  <CheckCircle className="w-6 h-6 text-orange-500 mt-1 flex-shrink-0" />
                  <div>
                    <h3 className="font-bold mb-1">Risco Zero</h3>
                    <p className="text-gray-300 text-sm">Você não tem nada a perder</p>
                  </div>
                </div>
              </div>
              <div className="mt-8 p-4 bg-gray-900 rounded-lg">
                <p className="text-orange-500 font-bold text-lg">
                  "Eu assumo todo o risco para que você não precise assumir nenhum."
                </p>
              </div>
            </div>
          </div>
        </LazySection>
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-gray-900" />}>
        <FAQ faqData={faqData} />
      </Suspense>

      <Suspense fallback={<div className="min-h-[200px] bg-black" />}>
        <LazySection className="py-16 px-4 bg-black">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-3xl md:text-4xl font-bold mb-8">
              Você pode seguir confiando na sorte... <span className="text-orange-500">ou assumir o controle.</span>
            </h2>
            <p className="text-xl text-gray-300 mb-8">
              A preparação começa com uma decisão. E a sua é agora.
            </p>
            <a href={paymentLink} target="_blank" rel="noopener noreferrer">
              <button className="bg-orange-500 hover:bg-orange-600 text-black font-bold py-4 px-8 rounded-lg text-2xl transition-all duration-300 transform hover:scale-105 mb-4">
                SIM, EU QUERO ESTAR PREPARADO
              </button>
            </a>
            <p className="text-sm text-gray-400">
              Não deixe para amanhã o que pode salvar sua vida hoje
            </p>
          </div>
        </LazySection>
      </Suspense>

      {/* Footer */}
      <footer className="bg-gray-900 py-8 px-4 text-center text-gray-400">
        <p>© 2024 Manual do Sobrevivencialista Moderno. Todos os direitos reservados.</p>
      </footer>
    </div>
  );
}

export default App;